@@ -24,7 +24,7 @@
 #
 
 
-from django.conf.urls.defaults import patterns
+from django.conf.urls import patterns
 
 from rbxmppnotification.extension import RBXmppNotification
 from rbxmppnotification.forms import RBXmppNotificationSettingsForm
