@@ -27,5 +27,3 @@ from django.shortcuts import render_to_response
 from django.template.context import RequestContext
 def configure(request, template_name="rbxmppnotification/configure.html"):
     return render_to_response(template_name, RequestContext(request, {}))
-def dashboard(request, template_name='rbxmppnotification/dashboard.html'):
-    return render_to_response(template_name, RequestContext(request))
